@@ -22,7 +22,7 @@ public class VariableDetails {
 	public static void main(String[] args) {
 		Vector v = new Vector(200);
 		for (int i = 0; i < 100; i++) {
-			v.add(new Integer(i));
+			v.add(Integer.valueOf(i));
 		}
 		System.out.println(v);
 	}
