@@ -142,6 +142,7 @@ import org.eclipse.jdt.debug.tests.state.RefreshStateTests;
 import org.eclipse.jdt.debug.tests.ui.DebugHoverTests;
 import org.eclipse.jdt.debug.tests.ui.DebugViewTests;
 import org.eclipse.jdt.debug.tests.ui.DetailPaneManagerTests;
+import org.eclipse.jdt.debug.tests.ui.JavaSnippetEditorTest;
 import org.eclipse.jdt.debug.tests.ui.OpenFromClipboardTests;
 import org.eclipse.jdt.debug.tests.ui.ViewManagementTests;
 import org.eclipse.jdt.debug.tests.ui.presentation.ModelPresentationTests;
@@ -153,6 +154,7 @@ import org.eclipse.jdt.debug.tests.variables.TestIntegerAccessUnboxing15;
 import org.eclipse.jdt.debug.tests.variables.TestLogicalStructures;
 import org.eclipse.jdt.debug.tests.variables.TestLogicalStructuresJava9;
 
+import junit.framework.JUnit4TestAdapter;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 
@@ -321,6 +323,9 @@ public class AutomatedSuite extends DebugSuite {
 		// Test was not stable, see bug 516024, the hope is that fix for bug 535686 helps
 		addTest(new TestSuite(DebugViewTests.class));
 
+	// Scrapbook editor tests
+		addTest(new TestSuite(JavaSnippetEditorTest.class));
+
 	// Debug hover tests
 		addTest(new TestSuite(DebugHoverTests.class));
 
@@ -332,7 +337,7 @@ public class AutomatedSuite extends DebugSuite {
 		addTest(new TestSuite(ModelPresentationTests.class));
 
 	// Open from Clipboard action tests - Need to use #suite() because the test has a custom setup
-		addTest(OpenFromClipboardTests.suite());
+		addTest(new JUnit4TestAdapter(OpenFromClipboardTests.class));
 
 	//add the complete eval suite
 		addTest(new TestSuite(GeneralEvalTests.class));
