@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.jdt.debug.tests.ui;
 
+import static org.junit.Assert.assertEquals;
+
 import java.util.ArrayList;
 import java.util.List;
 
@@ -38,18 +40,19 @@ import org.eclipse.jdt.internal.debug.ui.actions.OpenFromClipboardAction;
 import org.eclipse.jdt.launching.IVMInstall;
 import org.eclipse.jdt.launching.JavaRuntime;
 import org.eclipse.swt.widgets.Display;
+import org.junit.After;
+import org.junit.AfterClass;
 import org.junit.Assert;
-
-import junit.extensions.TestSetup;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
+import org.junit.Before;
+import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TestName;
 
 /**
  * Tests the Open from Clipboard action.
  */
-public class OpenFromClipboardTests extends TestCase {
+public class OpenFromClipboardTests {
 
 	/*
 	 * Copy of constants from OpenFromClipboardAction
@@ -78,88 +81,68 @@ public class OpenFromClipboardTests extends TestCase {
 
 	private Accessor fAccessor = new Accessor(OpenFromClipboardAction.class);
 
-	private static class MyTestSetup extends TestSetup {
+	public static IJavaProject fJProject;
 
-		public static IJavaProject fJProject;
+	@Rule
+	public TestName name = new TestName();
 
-		public MyTestSetup(Test test) {
-			super(test);
-		}
-
-		@Override
-		protected void setUp() throws Exception {
-			super.setUp();
-			JavaTestPlugin.enableAutobuild(false);
-			fJProject = createProject("OpenFromClipboardTests");
-			waitForEncodingRelatedJobs();
-		}
-
-		@Override
-		protected void tearDown() throws Exception {
-			fJProject.getProject().delete(true, true, null);
-			JavaTestPlugin.enableAutobuild(true);
-			super.tearDown();
-		}
-
-		protected void waitForEncodingRelatedJobs() {
-			TestUtil.waitForJobs("OpenFromClipboardTests", 10, 5_000, ValidateProjectEncoding.class);
-			TestUtil.waitForJobs("OpenFromClipboardTests", 10, 5_000, CharsetDeltaJob.FAMILY_CHARSET_DELTA);
-		}
-
-		private static IJavaProject createProject(String name) throws CoreException {
-			// delete any pre-existing project
-			IProject pro = ResourcesPlugin.getWorkspace().getRoot().getProject(name);
-			if (pro.exists()) {
-				pro.delete(true, true, null);
-			}
-
-			// create project
-			IJavaProject javaProject = JavaProjectHelper.createJavaProject(name, "bin");
-
-			// add rt.jar
-			IVMInstall vm = JavaRuntime.getDefaultVMInstall();
-			Assert.assertNotNull("No default JRE", vm);
-			JavaProjectHelper.addContainerEntry(javaProject, new Path(JavaRuntime.JRE_CONTAINER));
-			return javaProject;
-		}
+	@BeforeClass
+	public static void setUpClass() throws CoreException {
+		JavaTestPlugin.enableAutobuild(false);
+		fJProject = createProject("OpenFromClipboardTests");
+		waitForEncodingRelatedJobs();
 	}
 
-	public static Test suite() {
-		return new MyTestSetup(new TestSuite(OpenFromClipboardTests.class));
+	@AfterClass
+	public static void tearDownClass() throws CoreException {
+		fJProject.getProject().delete(true, true, null);
+		JavaTestPlugin.enableAutobuild(true);
 	}
 
-	public static Test setUpTest(Test someTest) {
-		return new MyTestSetup(someTest);
+	private static void waitForEncodingRelatedJobs() {
+		TestUtil.waitForJobs("OpenFromClipboardTests", 10, 5_000, ValidateProjectEncoding.class);
+		TestUtil.waitForJobs("OpenFromClipboardTests", 10, 5_000, CharsetDeltaJob.FAMILY_CHARSET_DELTA);
 	}
 
-	@Override
-	protected void setUp() throws Exception {
-		TestUtil.log(IStatus.INFO, getName(), "setUp");
-		super.setUp();
-		fSourceFolder = JavaProjectHelper.addSourceContainer(MyTestSetup.fJProject, "src");
+	private static IJavaProject createProject(String name) throws CoreException {
+		// delete any pre-existing project
+		IProject pro = ResourcesPlugin.getWorkspace().getRoot().getProject(name);
+		if (pro.exists()) {
+			pro.delete(true, true, null);
+		}
+
+		// create project
+		IJavaProject javaProject = JavaProjectHelper.createJavaProject(name, "bin");
+
+		// add rt.jar
+		IVMInstall vm = JavaRuntime.getDefaultVMInstall();
+		Assert.assertNotNull("No default JRE", vm);
+		JavaProjectHelper.addContainerEntry(javaProject, new Path(JavaRuntime.JRE_CONTAINER));
+		return javaProject;
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
-		TestUtil.log(IStatus.INFO, getName(), "tearDown");
-		JavaProjectHelper.removeSourceContainer(MyTestSetup.fJProject, "src");
-		super.tearDown();
+	@Before
+	public void setUp() throws Exception {
+		TestUtil.log(IStatus.INFO, name.getMethodName(), "setUp");
+		fSourceFolder = JavaProjectHelper.addSourceContainer(fJProject, "src");
 	}
 
-	private int getMatachingPattern(String s) {
+	@After
+	public void tearDown() throws Exception {
+		TestUtil.log(IStatus.INFO, name.getMethodName(), "tearDown");
+		JavaProjectHelper.removeSourceContainer(fJProject, "src");
+	}
+
+	private int getMatachingPattern(String s) throws Exception {
 		Object returnValue = fAccessor.invoke("getMatchingPattern", new Object[] { s });
 		return ((Integer) returnValue).intValue();
 	}
 
-	private List<?> getJavaElementMatches(final String textData) {
+	private List<?> getJavaElementMatches(final String textData) throws Exception {
 		JavaModelManager.getIndexManager().waitForIndex(false, null);
 		final List<?> matches = new ArrayList<>();
-		Display.getDefault().syncExec(new Runnable() {
-			@Override
-			public void run() {
-				fAccessor.invoke("getJavaElementMatches", new Class[] { String.class, List.class }, new Object[] { textData, matches });
-			}
-		});
+		Display.getDefault().syncCall(() -> fAccessor.invoke("getJavaElementMatches", new Class[] { String.class, List.class }, new Object[] {
+				textData, matches }));
 		return matches;
 	}
 
@@ -177,6 +160,7 @@ public class OpenFromClipboardTests extends TestCase {
 
 	}
 
+	@Test
 	public void testClassFileLine_1() throws Exception {
 		String s = "OpenFromClipboardTests.java:100";
 		assertEquals(JAVA_FILE_LINE, getMatachingPattern(s));
@@ -186,6 +170,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testClassFileLine_2() throws Exception {
 		String s = "OpenFromClipboardTests.java : 100";
 		assertEquals(JAVA_FILE_LINE, getMatachingPattern(s));
@@ -195,6 +180,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testClassFileLine_3() throws Exception {
 		String s = "OpenFromClipboard$Tests.java:100";
 		assertEquals(JAVA_FILE_LINE, getMatachingPattern(s));
@@ -204,6 +190,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testDBCS() throws Exception {
 		String typeName= "\u65b0\u898f\u30af\u30e9\u30b9";
 		String s= typeName + ".java:100";
@@ -216,6 +203,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testUmlaut() throws Exception {
 		String typeName= "\u0042\u006c\u00f6\u0064";
 		String s= typeName + ".java:100";
@@ -228,6 +216,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testClassFile_1() throws Exception {
 		String s = "OpenFromClipboardTests.java";
 		assertEquals(JAVA_FILE, getMatachingPattern(s));
@@ -237,6 +226,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testTypeLine_1() throws Exception {
 		String s = "OpenFromClipboardTests:100";
 		assertEquals(TYPE_LINE, getMatachingPattern(s));
@@ -246,6 +236,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testTypeLine_2() throws Exception {
 		String s = "OpenFromClipboardTests : 100";
 		assertEquals(TYPE_LINE, getMatachingPattern(s));
@@ -256,6 +247,7 @@ public class OpenFromClipboardTests extends TestCase {
 	}
 
 	// stack trace element tests
+	@Test
 	public void testStackTraceLine_1() throws Exception {
 		String s = "(OpenFromClipboardTests.java:121)";
 		assertEquals(STACK_TRACE_LINE, getMatachingPattern(s));
@@ -265,6 +257,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackTraceLine_2() throws Exception {
 		String s = "( OpenFromClipboardTests.java : 121 )";
 		assertEquals(STACK_TRACE_LINE, getMatachingPattern(s));
@@ -274,6 +267,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackTraceLine_3() throws Exception {
 		String s = "at p.OpenFromClipboardTests.getMatchingPattern(OpenFromClipboardTests.java:121)";
 		assertEquals(STACK_TRACE_LINE, getMatachingPattern(s));
@@ -283,6 +277,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackTraceLine_4() throws Exception {
 		String s = "OpenFromClipboardTests.getMatchingPattern(OpenFromClipboardTests.java:121)";
 		assertEquals(STACK_TRACE_LINE, getMatachingPattern(s));
@@ -292,6 +287,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackTraceLine_5() throws Exception {
 		String s = "OpenFromClipboardTests.getMatchingPattern ( OpenFromClipboardTests.java : 121 )";
 		assertEquals(STACK_TRACE_LINE, getMatachingPattern(s));
@@ -301,6 +297,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackTraceLine_6() throws Exception {
 		String s = "at p.OpenFromClipboard$Tests.getMatching$Pattern(OpenFromClipboardTests.java:121)";
 		setupTypeTest("OpenFromClipboardTests");
@@ -310,6 +307,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackTraceLine_7() throws Exception {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=349933#c2
 		String s = "getMatchingPattern ( OpenFromClipboardTests.java : 121 )";
@@ -336,6 +334,7 @@ public class OpenFromClipboardTests extends TestCase {
 		pack.createCompilationUnit("OpenFromClipboardTests.java", buf.toString(), false, null);
 	}
 
+	@Test
 	public void testMethod_1() throws Exception {
 		String s = "invokeOpenFromClipboardCommand()";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -345,6 +344,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_2() throws Exception {
 		String s = "invokeOpenFromClipboardCommand(String, int[], int)";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -354,6 +354,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_3() throws Exception {
 		String s = "OpenFromClipboardTests.invokeOpenFromClipboardCommand()";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -363,6 +364,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_4() throws Exception {
 		String s = "OpenFromClipboardTests.invokeOpenFromClipboardCommand(String, int[], int)";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -372,6 +374,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_5() throws Exception {
 		String s = "p.OpenFromClipboardTests.invokeOpenFromClipboardCommand()";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -381,6 +384,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_6() throws Exception {
 		String s = "p.OpenFromClipboardTests.invokeOpenFromClipboardCommand(String)";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -390,6 +394,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_7() throws Exception {
 		String s = "p.OpenFromClipboardTests.invokeOpenFromClipboardCommand(String, int[], int)";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -399,6 +404,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_8() throws Exception {
 		String s = "java.util.List.containsAll(Collection<?>)";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -425,6 +431,7 @@ public class OpenFromClipboardTests extends TestCase {
 		pack.createCompilationUnit("OpenFromClipboard$Tests.java", buf.toString(), false, null);
 	}
 
+	@Test
 	public void testMethod_9() throws Exception {
 		String s = "OpenFromClipboard$Tests.invokeOpenFromClipboardCommand()";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -434,6 +441,7 @@ public class OpenFromClipboardTests extends TestCase {
 		// performTest(s,1);
 	}
 
+	@Test
 	public void testMethod_10() throws Exception {
 		String s = "OpenFromClipboard$Tests.invokeOpenFromClipboardCommand(String)";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -443,6 +451,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMethod_11() throws Exception {
 		String s = "$.$$()";
 		assertEquals(METHOD, getMatachingPattern(s));
@@ -464,6 +473,7 @@ public class OpenFromClipboardTests extends TestCase {
 		pack.createCompilationUnit("OpenFromClipboardTests.java", buf.toString(), false, null);
 	}
 
+	@Test
 	public void testMember_1() throws Exception {
 		String s = "OpenFromClipboardTests#invokeOpenFromClipboardCommand";
 		assertEquals(MEMBER, getMatachingPattern(s));
@@ -473,6 +483,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMember_2() throws Exception {
 		String s = "p.OpenFromClipboardTests#invokeOpenFromClipboardCommand";
 		assertEquals(MEMBER, getMatachingPattern(s));
@@ -482,6 +493,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testMember_3() throws Exception {
 		String s = "p.OpenFromClipboardTests#invokeOpenFromClipboardCommand(String)";
 		assertEquals(METHOD_JAVADOC_REFERENCE, getMatachingPattern(s));
@@ -492,6 +504,7 @@ public class OpenFromClipboardTests extends TestCase {
 	}
 
 	// qualified name tests
+	@Test
 	public void testQualifiedName_1() throws Exception {
 		String s = "invokeOpenFromClipboardCommand";
 		assertEquals(QUALIFIED_NAME, getMatachingPattern(s));
@@ -504,6 +517,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testQualifiedName_2() throws Exception {
 		String s = "OpenFromClipboardTests.invokeOpenFromClipboardCommand";
 		assertEquals(QUALIFIED_NAME, getMatachingPattern(s));
@@ -513,6 +527,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testQualifiedName_3() throws Exception {
 		String s = "p.OpenFromClipboardTests.invokeOpenFromClipboardCommand";
 		assertEquals(QUALIFIED_NAME, getMatachingPattern(s));
@@ -541,6 +556,7 @@ public class OpenFromClipboardTests extends TestCase {
 		pack.createCompilationUnit("OpenFromClipboard$Tests.java", buf.toString(), false, null);
 	}
 
+	@Test
 	public void testQualifiedName_4() throws Exception {
 		String s = "$";
 		assertEquals(QUALIFIED_NAME, getMatachingPattern(s));
@@ -550,6 +566,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testQualifiedName_5() throws Exception {
 		String s = "$$";
 		assertEquals(QUALIFIED_NAME, getMatachingPattern(s));
@@ -559,6 +576,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testQualifiedName_6() throws Exception {
 		String s = "OpenFromClipboard$Tests";
 		assertEquals(QUALIFIED_NAME, getMatachingPattern(s));
@@ -580,6 +598,7 @@ public class OpenFromClipboardTests extends TestCase {
 		pack.createCompilationUnit("OpenFromClipboardTests.java", buf.toString(), false, null);
 	}
 
+	@Test
 	public void testStackElement_1() throws Exception {
 		String s = "p.OpenFromClipboardTests.invokeOpenFromClipboardCommand(char) line: 1456";
 		assertEquals(STACK, getMatachingPattern(s));
@@ -589,6 +608,7 @@ public class OpenFromClipboardTests extends TestCase {
 		assertEquals(1, matches.size());
 	}
 
+	@Test
 	public void testStackElement_2() throws Exception {
 		String s = "p.OpenFromClipboardTests.invokeOpenFromClipboardCommand(char): 1456";
 		assertEquals(STACK, getMatachingPattern(s));
@@ -599,16 +619,19 @@ public class OpenFromClipboardTests extends TestCase {
 	}
 
 	// invalid pattern tests
-	public void testInvalidPattern_1() {
+	@Test
+	public void testInvalidPattern_1() throws Exception {
 		String s = "(Collection)";
 		assertEquals(INVALID, getMatachingPattern(s));
 	}
 
-	public void testInvalidPattern_2() {
+	@Test
+	public void testInvalidPattern_2() throws Exception {
 		String s = "()";
 		assertEquals(INVALID, getMatachingPattern(s));
 	}
 
+	@Test
 	public void testInvalidPattern_3() throws Exception {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=426392#c6
 		String s = "java.lang.IllegalArgumentException\n" +
