@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -104,6 +104,7 @@ import org.osgi.service.prefs.BackingStoreException;
 /**
  * Plug-in class for the org.eclipse.jdt.debug.ui plug-in.
  */
+@SuppressWarnings("deprecation")
 public class JDIDebugUIPlugin extends AbstractUIPlugin {
 
 	/**
@@ -221,7 +222,7 @@ public class JDIDebugUIPlugin extends AbstractUIPlugin {
 	 * @return the active workbench window
 	 */
 	public static IWorkbenchWindow getActiveWorkbenchWindow() {
-		return getDefault().getWorkbench().getActiveWorkbenchWindow();
+		return PlatformUI.getWorkbench().getActiveWorkbenchWindow();
 	}
 
 	public static IWorkbenchPage getActivePage() {
