@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,10 +15,10 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.debug.eval.ast.engine;
 
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
-import java.util.Date;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.List;
@@ -80,6 +80,7 @@ import org.eclipse.jdt.internal.debug.eval.ast.instructions.InstructionSequence;
 import com.sun.jdi.InvocationException;
 import com.sun.jdi.ObjectReference;
 
+@SuppressWarnings("restriction")
 public class ASTEvaluationEngine implements IAstEvaluationEngine {
 	public static final String ANONYMOUS_VAR_PREFIX = "val$"; //$NON-NLS-1$
 	private static final int EVALUATION_DETAIL_BITMASK = DebugEvent.EVALUATION | DebugEvent.EVALUATION_IMPLICIT;
@@ -187,7 +188,7 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 	private void traceCaller(String snippet, IThread thread) {
 		if (JDIDebugOptions.DEBUG_AST_EVAL_THREAD_TRACE) {
 			StringBuilder buf = new StringBuilder();
-			buf.append(JDIDebugOptions.FORMAT.format(new Date()));
+			buf.append(JDIDebugOptions.FORMAT.format(Instant.now()));
 			buf.append(" : Evaluation Request Trace - Expression: "); //$NON-NLS-1$
 			buf.append(snippet);
 			buf.append("\n\tThread: "); //$NON-NLS-1$
@@ -389,7 +390,7 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 			Map<String, String> extraOptions = Collections.emptyMap();
 			// if target runtime is above java 1.8 then switch the compiler to debug mode to ignore java 9 module system
 			if (JavaCore.compareJavaVersions(((IJavaDebugTarget) frame.getDebugTarget()).getVersion(), JavaCore.VERSION_1_8) > 0) {
-				extraOptions = Collections.singletonMap(CompilerOptions.OPTION_JdtDebugCompileMode, JavaCore.ENABLED);
+				extraOptions = Collections.singletonMap(CompilerOptions.OPTION_IgnoreUnnamedModuleForSplitPackage, JavaCore.ENABLED);
 			}
 
 			unit = parseCompilationUnit(
@@ -420,15 +421,14 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 
 	private void scanAndFixSignature(String genericSignature, String erasureSignature, StringBuilder fixedSignature) {
 		/*
-		 * This actually fix variables which are type of Generic Types which cannot be resolved to a type in the current content. For example variable
-		 * type like P_OUT in java.util.stream.ReferencePipeline.filter(Predicate<? super P_OUT>)
+		 * This actually fix variables which are type of Generic Types which cannot be resolved to a type in the current context.
+		 * For example variable type like P_OUT in java.util.stream.ReferencePipeline.filter(Predicate<? super P_OUT>)
 		 *
 		 * and also generic signature such as Ljava/util/function/Predicate<+Ljava/util/List<Ljava/lang/Integer;>;>; Ljava/util/Comparator<-TT;>;
-		 * which will fail the properly resolved to the type.
+		 * which will fail to properly resolved to the type.
 		 */
 		if (genericSignature.startsWith(String.valueOf(Signature.C_TYPE_VARIABLE)) ||
 				genericSignature.startsWith(String.valueOf(Signature.C_CAPTURE)) ||
-				genericSignature.startsWith(String.valueOf(Signature.C_STAR)) ||
 				genericSignature.startsWith(String.valueOf(Signature.C_SUPER)))
 		{
 			fixedSignature.append(toDotQualified(erasureSignature));
@@ -445,6 +445,14 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 
 		String[] typeArguments = Signature.getTypeArguments(genericSignature);
 		if (typeArguments.length > 0) {
+			if (typeArguments.length == 1 &&
+					(typeArguments[0].equals(String.valueOf(Signature.C_STAR)) ||
+							typeArguments[0].startsWith(String.valueOf(new char[] { Signature.C_EXTENDS, Signature.C_TYPE_VARIABLE })))) {
+				// this is when we have recursive generics or we have a upper bound type variable
+				// so remove the generics to avoid compilation issues.
+				return;
+			}
+
 			fixedSignature.append(Signature.C_GENERIC_START);
 			for (int i = 0; i < typeArguments.length; i++) {
 				if (i > 0) {
@@ -479,7 +487,7 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 
 	private CompilationUnit parseCompilationUnit(char[] source,
 			String unitName, IJavaProject project, Map<String, String> extraCompileOptions) {
-		ASTParser parser = ASTParser.newParser(AST.JLS15);
+		ASTParser parser = ASTParser.newParser(AST.getJLSLatest());
 		parser.setSource(source);
 		parser.setUnitName(unitName);
 		parser.setProject(project);
@@ -678,7 +686,7 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 						|| problemId == IProblem.NotVisibleMethod
 						|| problemId == IProblem.NotVisibleConstructor
 						|| problemId == IProblem.NotVisibleField
-						|| problemId == IProblem.NotVisibleType 
+						|| problemId == IProblem.NotVisibleType
 						|| problemId == IProblem.UnexpectedStaticModifierForMethod) {
 					continue;
 				}
@@ -772,7 +780,7 @@ public class ASTEvaluationEngine implements IAstEvaluationEngine {
 		public void run() {
 			if (JDIDebugOptions.DEBUG_AST_EVAL) {
 				StringBuilder buf = new StringBuilder();
-				buf.append(JDIDebugOptions.FORMAT.format(new Date()));
+				buf.append(JDIDebugOptions.FORMAT.format(Instant.now()));
 				buf.append(" : AST Evaluation"); //$NON-NLS-1$
 				buf.append("\n\tExpression: "); //$NON-NLS-1$
 				buf.append(fExpression.getSnippet());
