@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -21,6 +21,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Stack;
 
 import org.eclipse.jdt.core.Flags;
@@ -91,6 +92,7 @@ import org.eclipse.jdt.core.dom.PrefixExpression;
 import org.eclipse.jdt.core.dom.PrimitiveType;
 import org.eclipse.jdt.core.dom.QualifiedName;
 import org.eclipse.jdt.core.dom.QualifiedType;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
 import org.eclipse.jdt.core.dom.ReturnStatement;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SimpleType;
@@ -162,9 +164,16 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 
 	private Stack<Map<String, String>> fTypeParameterStack = new Stack<>();
 	private Map<String, String> fMatchingTypeParameters = null;
+
+	private enum TypeParameterLocation {
+		TYPE, METHOD, EMPTY;
+	}
+
+	private Stack<TypeParameterLocation> fTypeParameterTypeStack = new Stack<>();
 	private CompilationUnit fCompilationUnit;
 	{
 		fTypeParameterStack.push(Collections.<String,String>emptyMap());
+		fTypeParameterTypeStack.push(TypeParameterLocation.EMPTY);
 	}
 
 	/**
@@ -204,10 +213,10 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 		} else {
 			num = sourceLevel;
 		}
-		fSourceMajorLevel = Integer.valueOf(num).intValue();
+		fSourceMajorLevel = Integer.parseInt(num);
 		if (index != -1) {
 			num = sourceLevel.substring(index + 1);
-			fSourceMinorLevel = Integer.valueOf(num).intValue();
+			fSourceMinorLevel = Integer.parseInt(num);
 		} else {
 			fSourceMinorLevel = 0;
 		}
@@ -309,7 +318,9 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 	 */
 	void adddTypeParameters(StringBuilder buffer) {
 		if (isSourceLevelGreaterOrEqual(1, 5)) {
-			Collection<String> activeTypeParameters = (fMatchingTypeParameters != null ? fMatchingTypeParameters : fTypeParameterStack.peek()).values();
+			Collection<String> activeTypeParameters = Optional.ofNullable(fMatchingTypeParameters)
+					.map(Map::values).orElse(Collections.emptyList());
+
 			if (!activeTypeParameters.isEmpty()) {
 				Iterator<String> iterator = activeTypeParameters.iterator();
 				buffer.append(Signature.C_GENERIC_START);
@@ -444,6 +455,11 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 						.equals(fLastTypeName)) {
 					source.append(buildEnumDeclaration(null, enumDeclaration));
 				}
+			} else if (bodyDeclaration instanceof RecordDeclaration) {
+				var recordDeclaration = (RecordDeclaration) bodyDeclaration;
+				if (!recordDeclaration.getName().getIdentifier().equals(fLastTypeName)) {
+					source.append(buildRecordDeclaration(null, recordDeclaration));
+				}
 			}
 		}
 		return source;
@@ -524,16 +540,14 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 		appendExtraDimensions(source, methodDeclaration.getExtraDimensions());
 
 		first = true;
-		for (Iterator<Name> iterator = methodDeclaration.thrownExceptions()
-				.iterator(); iterator.hasNext();) {
-			Name name = iterator.next();
+		for (Object exceptionType : methodDeclaration.thrownExceptionTypes()) {
 			if (first) {
 				first = false;
 				source.append(" throws "); //$NON-NLS-1$
 			} else {
 				source.append(',');
 			}
-			source.append(getQualifiedIdentifier(name));
+			source.append(getTypeName((Type) exceptionType));
 		}
 
 		if (Flags.isAbstract(modifiers) || Flags.isNative(modifiers)) {
@@ -600,7 +614,71 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 
 		source.append(typeDeclaration.getName().getIdentifier());
 
-		List<TypeParameter> typeParameters = typeDeclaration.typeParameters();
+		buildTypeParameterList(source, typeDeclaration.typeParameters());
+
+		Type superClass = typeDeclaration.getSuperclassType();
+		if (superClass != null) {
+			source.append(" extends "); //$NON-NLS-1$
+			source.append(getTypeName(superClass));
+		}
+
+		buildSuperInterfaceTypeList(source, typeDeclaration.superInterfaceTypes().iterator(), typeDeclaration.isInterface());
+
+		if (buffer != null) {
+			fSnippetStartPosition += source.length();
+		}
+		source.append(buildTypeBody(buffer, typeDeclaration.bodyDeclarations()));
+
+		return source;
+	}
+
+	void buildSuperInterfaceTypeList(StringBuilder source, Iterator<Type> superInterfaceTypes, boolean isTypeInterface) {
+		if (superInterfaceTypes.hasNext()) {
+			if (isTypeInterface) {
+				source.append(" extends "); //$NON-NLS-1$
+			} else {
+				source.append(" implements "); //$NON-NLS-1$
+			}
+			source.append(getTypeName(superInterfaceTypes.next()));
+			while (superInterfaceTypes.hasNext()) {
+				source.append(',');
+				source.append(getTypeName(superInterfaceTypes.next()));
+			}
+		}
+	}
+
+	private StringBuilder buildRecordDeclaration(StringBuilder buffer, RecordDeclaration typeDeclaration) {
+
+		StringBuilder source = new StringBuilder();
+		source.append(Flags.toString(typeDeclaration.getModifiers()));
+		source.append(" record "); //$NON-NLS-1$
+
+		source.append(typeDeclaration.getName().getIdentifier());
+
+		buildTypeParameterList(source, typeDeclaration.typeParameters());
+
+		boolean first = true;
+		source.append('(');
+		for (SingleVariableDeclaration field : (List<SingleVariableDeclaration>) typeDeclaration.recordComponents()) {
+			if (first) {
+				first = false;
+			} else {
+				source.append(',');
+			}
+			source.append(getTypeName(field.getType())).append(' ').append(field.getName());
+		}
+		source.append(')');
+		buildSuperInterfaceTypeList(source, typeDeclaration.superInterfaceTypes().iterator(), false);
+
+		if (buffer != null) {
+			fSnippetStartPosition += source.length();
+		}
+		source.append(buildTypeBody(buffer, typeDeclaration.bodyDeclarations()));
+
+		return source;
+	}
+
+	void buildTypeParameterList(StringBuilder source, List<TypeParameter> typeParameters) {
 		if (!typeParameters.isEmpty() && isSourceLevelGreaterOrEqual(1, 5)) {
 			source.append('<');
 			Iterator<TypeParameter> iter = typeParameters.iterator();
@@ -633,33 +711,6 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 			}
 			source.append('>');
 		}
-
-		Type superClass = typeDeclaration.getSuperclassType();
-		if (superClass != null) {
-			source.append(" extends "); //$NON-NLS-1$
-			source.append(getTypeName(superClass));
-		}
-
-		Iterator<Type> iter = typeDeclaration.superInterfaceTypes().iterator();
-		if (iter.hasNext()) {
-			if (typeDeclaration.isInterface()) {
-				source.append(" extends "); //$NON-NLS-1$
-			} else {
-				source.append(" implements "); //$NON-NLS-1$
-			}
-			source.append(getTypeName(iter.next()));
-			while (iter.hasNext()) {
-				source.append(',');
-				source.append(getTypeName(iter.next()));
-			}
-		}
-
-		if (buffer != null) {
-			fSnippetStartPosition += source.length();
-		}
-		source.append(buildTypeBody(buffer, typeDeclaration.bodyDeclarations()));
-
-		return source;
 	}
 
 	private StringBuilder buildCompilationUnit(StringBuilder buffer,
@@ -803,7 +854,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 			}
 			return name;
 		} else if (type.isArrayType()) {
-			return getTypeName(((ArrayType) type).getComponentType()) + "[]"; //$NON-NLS-1$
+			return getTypeName(((ArrayType) type).getElementType()) + "[]"; //$NON-NLS-1$
 		} else if (type.isPrimitiveType()) {
 			return ((PrimitiveType) type).getPrimitiveTypeCode().toString();
 		} else if (type.isQualifiedType()) {
@@ -984,6 +1035,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 	 *            the {@link Type}
 	 * @return the parent {@link Type}
 	 */
+	@SuppressWarnings("deprecation")
 	private Type getParentType(Type type) {
 		if (type instanceof ArrayType) {
 			return getParentType(((ArrayType) type).getComponentType());
@@ -1073,6 +1125,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 	@Override
 	public void endVisit(MethodDeclaration node) {
 		fTypeParameterStack.pop();
+		fTypeParameterTypeStack.pop();
 	}
 
 	/**
@@ -1080,9 +1133,9 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 	 */
 	@Override
 	public void endVisit(TypeDeclaration node) {
-
 		if (hasError()) {
 			fTypeParameterStack.pop();
+			fTypeParameterTypeStack.pop();
 			return;
 		}
 
@@ -1096,6 +1149,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 		if (!fEvaluateNextEndTypeDeclaration) {
 			fEvaluateNextEndTypeDeclaration = true;
 			fTypeParameterStack.pop();
+			fTypeParameterTypeStack.pop();
 			return;
 		}
 
@@ -1130,6 +1184,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 			}
 		}
 		fTypeParameterStack.pop();
+		fTypeParameterTypeStack.pop();
 	}
 
 	/*
@@ -1607,8 +1662,9 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 		int lastLine = fCompilationUnit.getLineNumber(node.getStartPosition() + node.getLength());
 
 		List<TypeParameter> typeParameters = node.typeParameters();
-		pushTypeParameters(typeParameters);
-		if (isRightType(node.getParent()) && firstLine <= fLine && fLine <= lastLine) {
+		pushTypeParameters(typeParameters, TypeParameterLocation.METHOD);
+		if (isRightType(node.getParent()) && firstLine <= fLine && fLine <= lastLine
+				&& fTypeParameterTypeStack.peek() == TypeParameterLocation.METHOD) {
 				fMatchingTypeParameters  = fTypeParameterStack.peek();
 		}
 		if (rightTypeFound()) {
@@ -1617,7 +1673,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 		return true;
 	}
 
-	private void pushTypeParameters(List<TypeParameter> typeParameters) {
+	private void pushTypeParameters(List<TypeParameter> typeParameters, TypeParameterLocation location) {
 		if (!typeParameters.isEmpty()) {
 			HashMap<String,String> newTypeParameters = new HashMap<>(fTypeParameterStack.peek());
 			Iterator<TypeParameter> iterator = typeParameters.iterator();
@@ -1627,8 +1683,10 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 				newTypeParameters.put(boundName, typeParameter.toString());
 			}
 			fTypeParameterStack.push(newTypeParameters); // Push the new "scope"
+			fTypeParameterTypeStack.push(location);
 		} else {
 			fTypeParameterStack.push(fTypeParameterStack.peek()); // Push the same
+			fTypeParameterTypeStack.push(fTypeParameterTypeStack.peek());
 		}
 	}
 
@@ -2019,7 +2077,7 @@ public class SourceBasedSourceGenerator extends ASTVisitor {
 	@Override
 	public boolean visit(TypeDeclaration node) {
 		List<TypeParameter> typeParameters = node.typeParameters();
-		pushTypeParameters(typeParameters);
+		pushTypeParameters(typeParameters, TypeParameterLocation.TYPE);
 		if (rightTypeFound()) {
 			fEvaluateNextEndTypeDeclaration = false;
 			return false;
