@@ -18,10 +18,11 @@ import java.io.DataInputStream;
 import java.io.DataOutputStream;
 import java.io.IOException;
 import java.io.PrintWriter;
-import java.util.Date;
+import java.time.Instant;
 import java.util.Map;
 
 import org.eclipse.jdi.Bootstrap;
+import org.eclipse.jdi.TimeoutException;
 import org.eclipse.jdi.internal.jdwp.JdwpCommandPacket;
 import org.eclipse.jdi.internal.jdwp.JdwpPacket;
 import org.eclipse.jdi.internal.jdwp.JdwpReplyPacket;
@@ -68,10 +69,7 @@ public class MirrorImpl implements Mirror {
 	public MirrorImpl(String description) {
 		fDescription = description;
 		fVirtualMachineImpl = (VirtualMachineImpl) this;
-		PrintWriter writer = ((VirtualMachineManagerImpl) org.eclipse.jdi.Bootstrap
-				.virtualMachineManager()).verbosePrintWriter();
-		if (writer != null)
-			fVerboseWriter = new VerboseWriter(writer);
+		initVerboseWriter();
 	}
 
 	/**
@@ -80,10 +78,18 @@ public class MirrorImpl implements Mirror {
 	public MirrorImpl(String description, VirtualMachineImpl virtualMachineImpl) {
 		fVirtualMachineImpl = virtualMachineImpl;
 		fDescription = description;
-		PrintWriter writer = ((VirtualMachineManagerImpl) org.eclipse.jdi.Bootstrap
-				.virtualMachineManager()).verbosePrintWriter();
-		if (writer != null)
+		initVerboseWriter();
+	}
+
+	private void initVerboseWriter() {
+		if (!VirtualMachineManagerImpl.isVerboseTracingEnabled()) {
+			return;
+		}
+		VirtualMachineManagerImpl machineManagerImpl = (VirtualMachineManagerImpl) org.eclipse.jdi.Bootstrap.virtualMachineManager();
+		PrintWriter writer = machineManagerImpl.verbosePrintWriter();
+		if (writer != null) {
 			fVerboseWriter = new VerboseWriter(writer);
+		}
 	}
 
 	/**
@@ -129,9 +135,16 @@ public class MirrorImpl implements Mirror {
 	/**
 	 * Processing after each Jdwp Event.
 	 */
-	public void handledJdwpEventSet() {
+	public void handledJdwpEventSet(Throwable t) {
 		if (fVerboseWriter != null) {
-			fVerboseWriter.println();
+			if (t instanceof TimeoutException || t instanceof VMDisconnectedException) {
+				// do nothing
+			} else {
+				if (t != null) {
+					fVerboseWriter.printStackTrace(t);
+				}
+				fVerboseWriter.println();
+			}
 			fVerboseWriter.flush();
 		}
 	}
@@ -196,7 +209,7 @@ public class MirrorImpl implements Mirror {
 		long recieved = System.currentTimeMillis();
 		if (JDIDebugOptions.DEBUG_JDI_REQUEST_TIMES) {
 			StringBuilder buf = new StringBuilder();
-			buf.append(JDIDebugOptions.FORMAT.format(new Date(sent)));
+			buf.append(JDIDebugOptions.FORMAT.format(Instant.ofEpochMilli(sent)));
 			buf.append(" JDI Request: "); //$NON-NLS-1$
 			buf.append(commandPacket.toString());
 			buf.append("\n\tResponse Time: "); //$NON-NLS-1$
@@ -332,8 +345,9 @@ public class MirrorImpl implements Mirror {
 	 */
 	public void checkVM(Mirror mirror) throws VMMismatchException {
 		if (((MirrorImpl) mirror).virtualMachineImpl() != this
-				.virtualMachineImpl())
+				.virtualMachineImpl()) {
 			throw new VMMismatchException();
+		}
 	}
 
 	/**
