@@ -276,8 +276,9 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	public final void removeKnownRefType(String signature) {
 		List<ReferenceType> refTypeList = classesBySignature(signature);
-		if (refTypeList.isEmpty())
+		if (refTypeList.isEmpty()) {
 			return;
+		}
 
 		// If we have only one known class for this signature, we known that
 		// this is the class
@@ -313,9 +314,10 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 * HCR.
 	 */
 	public void checkHCRSupported() throws UnsupportedOperationException {
-		if (!isHCRSupported())
+		if (!isHCRSupported()) {
 			throw new UnsupportedOperationException(
 					NLS.bind(JDIMessages.VirtualMachineImpl_Target_VM__0__does_not_support_Hot_Code_Replacement_1, new String[] { name() }));
+		}
 	}
 
 	/*
@@ -448,8 +450,9 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 * Retrieve this VM's capabilities.
 	 */
 	public void getCapabilities() {
-		if (fGotCapabilities)
+		if (fGotCapabilities) {
 			return;
+		}
 
 		int command = JdwpCommandPacket.VM_CAPABILITIES;
 		if (isJdwpVersionGreaterOrEqual(1, 4)) {
@@ -751,7 +754,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public ByteValue mirrorOf(byte value) {
-		return new ByteValueImpl(virtualMachineImpl(), new Byte(value));
+		return new ByteValueImpl(virtualMachineImpl(), Byte.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -759,7 +762,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public CharValue mirrorOf(char value) {
-		return new CharValueImpl(virtualMachineImpl(), new Character(value));
+		return new CharValueImpl(virtualMachineImpl(), Character.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -767,7 +770,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public DoubleValue mirrorOf(double value) {
-		return new DoubleValueImpl(virtualMachineImpl(), new Double(value));
+		return new DoubleValueImpl(virtualMachineImpl(), Double.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -775,7 +778,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public FloatValue mirrorOf(float value) {
-		return new FloatValueImpl(virtualMachineImpl(), new Float(value));
+		return new FloatValueImpl(virtualMachineImpl(), Float.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -783,7 +786,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public IntegerValue mirrorOf(int value) {
-		return new IntegerValueImpl(virtualMachineImpl(), new Integer(value));
+		return new IntegerValueImpl(virtualMachineImpl(), Integer.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -791,7 +794,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public LongValue mirrorOf(long value) {
-		return new LongValueImpl(virtualMachineImpl(), new Long(value));
+		return new LongValueImpl(virtualMachineImpl(), Long.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -799,7 +802,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 */
 	@Override
 	public ShortValue mirrorOf(short value) {
-		return new ShortValueImpl(virtualMachineImpl(), new Short(value));
+		return new ShortValueImpl(virtualMachineImpl(), Short.valueOf(value));
 	}
 
 	/* (non-Javadoc)
@@ -968,8 +971,9 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 * Request and fetch ID sizes of Virtual Machine.
 	 */
 	private void getIDSizes() {
-		if (fGotIDSizes)
+		if (fGotIDSizes) {
 			return;
+		}
 
 		/*
 		 * fGotIDSizes must first be assigned true to prevent an infinite loop
@@ -1005,8 +1009,9 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 * Retrieves version info of the VM.
 	 */
 	public void getVersionInfo() {
-		if (fVersionDescription != null)
+		if (fVersionDescription != null) {
 			return;
+		}
 
 		initJdwpRequest();
 		try {
@@ -1038,8 +1043,9 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	 * Retrieves the HCR capabilities of the VM.
 	 */
 	public void getHCRCapabilities() {
-		if (fHcrCapabilities != null)
+		if (fHcrCapabilities != null) {
 			return;
+		}
 		fHcrCapabilities = new boolean[HCR_CAN_REENTER_ON_EXIT + 1];
 
 		if (isHCRSupported()) {
@@ -1198,7 +1204,7 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 			try {
 				String name = field.getName();
 				if (name.startsWith("HCR_RELOAD_")) { //$NON-NLS-1$
-					Integer intValue = new Integer(field.getInt(null));
+					Integer intValue = Integer.valueOf(field.getInt(null));
 					name = name.substring(4);
 					fgHCRResultMap.put(intValue, name);
 				}
@@ -1603,4 +1609,8 @@ public class VirtualMachineImpl extends MirrorImpl implements VirtualMachine,
 	public boolean canBeModified() {
 		return true;
 	}
+
+	public boolean mayCreateVirtualThreads() {
+		return isJdwpVersionGreaterOrEqual(19, 0);
+	}
 }
