@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2018, 2019 Cedric Chabanois and others.
+ * Copyright (c) 2018, 2023 Cedric Chabanois and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,8 +14,6 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.launching;
 
-import static org.eclipse.jdt.internal.launching.LaunchingPlugin.LAUNCH_TEMP_FILE_PREFIX;
-
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -34,6 +32,7 @@ import java.util.jar.Manifest;
 
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.Status;
@@ -68,6 +67,7 @@ public class ClasspathShortener implements IProcessTempFileCreator {
 	private String[] envp;
 	private File processTempFilesDir;
 	private final List<File> processTempFiles = new ArrayList<>();
+	private static final String ARGFILE_TEMPDIR_NAME = "temp"; //$NON-NLS-1$
 
 	/**
 	 *
@@ -293,9 +293,14 @@ public class ClasspathShortener implements IProcessTempFileCreator {
 		String path = cmdLine.get(modulePathArgumentIndex);
 		File file;
 		try {
-			String timeStamp = getLaunchTimeStamp();
-			File argFile = new File(processTempFilesDir, String.format(LAUNCH_TEMP_FILE_PREFIX + "%s" + option //$NON-NLS-1$
-					+ "-arg-%s.txt", getLaunchConfigurationName(), timeStamp)); //$NON-NLS-1$
+			IPath stateLocation = LaunchingPlugin.getDefault().getStateLocation();
+			IPath argFileTmpIPath = stateLocation.append(ARGFILE_TEMPDIR_NAME);
+			File argFileTmpDir = argFileTmpIPath.toFile();
+			if (!argFileTmpDir.exists()) {
+				Files.createDirectory(argFileTmpDir.toPath());
+			}
+			File argFile = JavaLaunchingUtils.createFileForArgument(getLaunchTimeStamp(), argFileTmpDir, getLaunchConfigurationName(), "%s" //$NON-NLS-1$
+					+ option + "-arg-%s.txt"); //$NON-NLS-1$
 
 			String arg = option + " " + quoteWindowsPath(path); //$NON-NLS-1$
 			Charset systemCharset = Platform.getSystemCharset();
@@ -305,6 +310,7 @@ public class ClasspathShortener implements IProcessTempFileCreator {
 						+ systemCharset.displayName() + ".", null)); //$NON-NLS-1$
 			}
 			Files.writeString(argFile.toPath(), arg, systemCharset);
+			argFile.deleteOnExit();
 			file = argFile;
 		} catch (IOException e) {
 			throw new CoreException(new Status(IStatus.ERROR, LaunchingPlugin.getUniqueIdentifier(), IStatus.ERROR, "Cannot create " + option //$NON-NLS-1$
@@ -343,9 +349,7 @@ public class ClasspathShortener implements IProcessTempFileCreator {
 
 	private File createClasspathOnlyJar(String classpath) throws CoreException {
 		try {
-			String timeStamp = getLaunchTimeStamp();
-			File jarFile = new File(processTempFilesDir, String.format(LAUNCH_TEMP_FILE_PREFIX
-					+ "%s-classpathOnly-%s.jar", getLaunchConfigurationName(), timeStamp)); //$NON-NLS-1$
+			File jarFile = JavaLaunchingUtils.createFileForArgument(getLaunchTimeStamp(), processTempFilesDir, getLaunchConfigurationName(), "%s-classpathOnly-%s.jar"); //$NON-NLS-1$
 			URI workingDirUri = processTempFilesDir.toURI();
 			StringBuilder manifestClasspath = new StringBuilder();
 			String[] classpathArray = getClasspathAsArray(classpath);
@@ -386,11 +390,7 @@ public class ClasspathShortener implements IProcessTempFileCreator {
 	}
 
 	protected String getLaunchTimeStamp() {
-		String timeStamp = launch.getAttribute(DebugPlugin.ATTR_LAUNCH_TIMESTAMP);
-		if (timeStamp == null) {
-			timeStamp = Long.toString(System.currentTimeMillis());
-		}
-		return timeStamp;
+		return JavaLaunchingUtils.getLaunchTimeStamp(launch);
 	}
 
 	private String[] getEnvpFromNativeEnvironment() {
