@@ -249,4 +249,8 @@ public class LaunchingMessages extends NLS {
 
 	public static String RunnerBootpathPError;
 
+	public static String lookupInstalledJVMs;
+
+	public static String configuringJVM;
+
 }
