@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -35,7 +35,6 @@ import java.util.Map;
 import java.util.Map.Entry;
 
 import javax.xml.parsers.DocumentBuilder;
-import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.FactoryConfigurationError;
 import javax.xml.parsers.ParserConfigurationException;
 
@@ -153,6 +152,7 @@ public class LaunchingPlugin extends Plugin implements DebugOptionsListener, IEc
 	private boolean fIgnoreVMDefPropertyChangeEvents = false;
 
 	private static final String EMPTY_STRING = "";    //$NON-NLS-1$
+	public static final String PREF_DETECT_VMS_AT_STARTUP = "detectVMsAtStartup"; //$NON-NLS-1$
 
 	/**
 	 * Mapping of top-level VM installation directories to library info for that
@@ -582,7 +582,6 @@ public class LaunchingPlugin extends Plugin implements DebugOptionsListener, IEc
 		ResourcesPlugin.getWorkspace().addResourceChangeListener(this, IResourceChangeEvent.PRE_DELETE | IResourceChangeEvent.PRE_CLOSE);
 		DebugPlugin.getDefault().getLaunchManager().addLaunchListener(this);
 		DebugPlugin.getDefault().addDebugEventListener(this);
-
 		AdvancedSourceLookupSupport.start();
 	}
 
@@ -946,9 +945,8 @@ public class LaunchingPlugin extends Plugin implements DebugOptionsListener, IEc
 		libPath = libPath.append("libraryInfos.xml"); //$NON-NLS-1$
 		File file = libPath.toFile();
 		if (file.exists()) {
-			try {
-				InputStream stream = new BufferedInputStream(new FileInputStream(file));
-				DocumentBuilder parser = DocumentBuilderFactory.newInstance().newDocumentBuilder();
+			try (InputStream stream = new BufferedInputStream(new FileInputStream(file))) {
+				DocumentBuilder parser = XmlProcessorFactoryJdtDebug.createDocumentBuilderWithErrorOnDOCTYPE();
 				parser.setErrorHandler(new DefaultHandler());
 				Element root = parser.parse(new InputSource(stream)).getDocumentElement();
 				if(!root.getNodeName().equals("libraryInfos")) { //$NON-NLS-1$
@@ -1040,9 +1038,8 @@ public class LaunchingPlugin extends Plugin implements DebugOptionsListener, IEc
 		libPath = libPath.append(".install.xml"); //$NON-NLS-1$
 		File file = libPath.toFile();
 		if (file.exists()) {
-			try {
-				InputStream stream = new BufferedInputStream(new FileInputStream(file));
-				DocumentBuilder parser = DocumentBuilderFactory.newInstance().newDocumentBuilder();
+			try (InputStream stream = new BufferedInputStream(new FileInputStream(file))) {
+				DocumentBuilder parser = XmlProcessorFactoryJdtDebug.createDocumentBuilderWithErrorOnDOCTYPE();
 				parser.setErrorHandler(new DefaultHandler());
 				Element root = parser.parse(new InputSource(stream)).getDocumentElement();
 				if(root.getNodeName().equalsIgnoreCase("dirs")) { //$NON-NLS-1$
@@ -1230,7 +1227,7 @@ public class LaunchingPlugin extends Plugin implements DebugOptionsListener, IEc
 	public static DocumentBuilder getParser() throws CoreException {
 		if (fgXMLParser == null) {
 			try {
-				fgXMLParser = DocumentBuilderFactory.newInstance().newDocumentBuilder();
+				fgXMLParser = XmlProcessorFactoryJdtDebug.createDocumentBuilderWithErrorOnDOCTYPE();
 				fgXMLParser.setErrorHandler(new DefaultHandler());
 			} catch (ParserConfigurationException e) {
 				abort(LaunchingMessages.LaunchingPlugin_34, e);
@@ -1351,4 +1348,5 @@ public class LaunchingPlugin extends Plugin implements DebugOptionsListener, IEc
 	public static void trace(String message) {
 		trace(null, message, null);
 	}
+
 }
\ No newline at end of file
