@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2000, 2019 IBM Corporation and others.
+ *  Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -24,7 +24,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.stream.Collectors;
-import java.util.stream.Stream;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
@@ -81,13 +80,31 @@ public class StandardVMRunner extends AbstractVMRunner {
 
 	/**
 	 * Returns the 'rendered' name for the specified command line
-	 * @param commandLine the command line
-	 * @param timestamp the run-at time for the process
+	 *
+	 * @param p
+	 * @param commandLine
+	 *            the command line
+	 * @param timestamp
+	 *            the run-at time for the process
 	 * @return the name for the process
 	 */
-	public static String renderProcessLabel(String[] commandLine, String timestamp) {
-		String format= LaunchingMessages.StandardVMRunner__0____1___2;
-		return NLS.bind(format, new String[] { commandLine[0], timestamp });
+	public static String renderProcessLabel(Process p, String[] commandLine, String timestamp) {
+		String processId = getProcessId(p);
+		if (processId == null) {
+			String format = LaunchingMessages.StandardVMRunner__0____1___2;
+			return NLS.bind(format, new String[] { commandLine[0], timestamp });
+		}
+		String format = LaunchingMessages.StandardVMRunner__0____1___2_3;
+		return NLS.bind(format, new String[] { commandLine[0], timestamp, processId });
+	}
+
+	private static String getProcessId(Process p) {
+		try {
+			return p != null ? Long.toString(p.pid()) : null;
+		} catch (UnsupportedOperationException e) {
+			// ignore, pid() is not implemented in this JVM
+		}
+		return null;
 	}
 
 	/**
@@ -316,30 +333,45 @@ public class StandardVMRunner extends AbstractVMRunner {
 	}
 
 	/**
-	 * This method is used to ensure that the JVM file encoding matches that of the console preference for file encoding.
-	 * If the user explicitly declares a file encoding in the launch configuration, then that file encoding is used.
+	 * This method is used to ensure that the JVM file encoding matches that of the console preference for file encoding. If the user explicitly
+	 * declares a file encoding in the launch configuration, then that file encoding is used.
 	 *
-	 * @param launch the {@link Launch}
-	 * @param vmargs the original listing of JVM arguments
+	 * @param launch
+	 *            the {@link Launch}
+	 * @param vmargs
+	 *            the original listing of JVM arguments
 	 * @return the listing of JVM arguments including file encoding if one was not specified
 	 *
 	 * @since 3.4
+	 * @see {@link System#out} for Java >=19 *
+	 * @see {@link System#err} for Java >=19 *
 	 */
 	protected String[] ensureEncoding(ILaunch launch, String[] vmargs) {
-		boolean foundencoding = false;
+		String encoding = launch.getAttribute(DebugPlugin.ATTR_CONSOLE_ENCODING);
+		// XXX JDKs Javadoc specifies:
+		// "values other than UTF-8 (or COMPAT for file.encoding) leads to unspecified behavior"
+		//
+		// However it works fine on systems that support the specified encoding.
+		vmargs = ensureArgument("-Dfile.encoding=", encoding, vmargs); //$NON-NLS-1$
+		vmargs = ensureArgument("-Dstdout.encoding=", encoding, vmargs); //$NON-NLS-1$
+		vmargs = ensureArgument("-Dstderr.encoding=", encoding, vmargs); //$NON-NLS-1$
+		return vmargs;
+	}
+
+	protected String[] ensureArgument(String argument, String value, String[] vmargs) {
+		boolean foundArgument = false;
 		for (String vmarg : vmargs) {
-			if(vmarg.startsWith("-Dfile.encoding=")) { //$NON-NLS-1$
-				foundencoding = true;
+			if (vmarg.startsWith(argument)) {
+				foundArgument = true;
 			}
 		}
-		if(!foundencoding) {
-			String encoding = launch.getAttribute(DebugPlugin.ATTR_CONSOLE_ENCODING);
-			if(encoding == null) {
+		if (!foundArgument) {
+			if (value == null) {
 				return vmargs;
 			}
 			String[] newargs = new String[vmargs.length+1];
 			System.arraycopy(vmargs, 0, newargs, 0, vmargs.length);
-			newargs[newargs.length-1] = "-Dfile.encoding="+encoding; //$NON-NLS-1$
+			newargs[newargs.length - 1] = argument + value;
 			return newargs;
 		}
 		return vmargs;
@@ -349,8 +381,7 @@ public class StandardVMRunner extends AbstractVMRunner {
 		private String[] commandLine;
 		private String[] envp;
 		private File workingDir;
-		private ClasspathShortener classpathShortener;
-		private CommandLineShortener commandLineShortener;
+		private IProcessTempFileCreator commandLineShortener;
 		private int port;
 
 		public String[] getEnvp() {
@@ -377,19 +408,11 @@ public class StandardVMRunner extends AbstractVMRunner {
 			this.workingDir = workingDir;
 		}
 
-		public ClasspathShortener getClasspathShortener() {
-			return classpathShortener;
-		}
-
-		public void setClasspathShortener(ClasspathShortener classpathShortener) {
-			this.classpathShortener = classpathShortener;
-		}
-
-		public CommandLineShortener getCommandLineShortener() {
+		public IProcessTempFileCreator getCommandLineShortener() {
 			return commandLineShortener;
 		}
 
-		public void setCommandLineShortener(CommandLineShortener commandLineShortener) {
+		public void setCommandLineShortener(IProcessTempFileCreator commandLineShortener) {
 			this.commandLineShortener = commandLineShortener;
 		}
 
@@ -476,25 +499,27 @@ public class StandardVMRunner extends AbstractVMRunner {
 		String[] cmdLine= new String[arguments.size()];
 		arguments.toArray(cmdLine);
 		File workingDir = getWorkingDir(config);
-		ClasspathShortener classpathShortener = new ClasspathShortener(fVMInstance, launch, cmdLine, lastVMArgumentIndex, workingDir, envp);
-		if (classpathShortener.shortenCommandLineIfNecessary()) {
-			cmdLine = classpathShortener.getCmdLine();
-			envp = classpathShortener.getEnvp();
+		CommandDetails cmd = new CommandDetails();
+		CommandLineShortener commandLineShortener = new CommandLineShortener(fVMInstance, launch, cmdLine, workingDir);
+		if (commandLineShortener.shouldShortenCommandLine()) {
+			cmdLine = commandLineShortener.shortenCommandLine();
+			cmd.setCommandLineShortener(commandLineShortener);
+		} else {
+			ClasspathShortener classpathShortener = new ClasspathShortener(fVMInstance, launch, cmdLine, lastVMArgumentIndex, workingDir, envp);
+			if (classpathShortener.shortenCommandLineIfNecessary()) {
+				cmdLine = classpathShortener.getCmdLine();
+				envp = classpathShortener.getEnvp();
+			}
+			cmd.setCommandLineShortener(classpathShortener);
 		}
 		String[] newCmdLine = validateCommandLine(launchConfiguration, cmdLine);
 		if (newCmdLine != null) {
 			cmdLine = newCmdLine;
 		}
-		CommandLineShortener commandLineShortener = new CommandLineShortener(fVMInstance, launch, newCmdLine, workingDir);
-		if (commandLineShortener.shouldShortenCommandLine()) {
-			cmdLine = commandLineShortener.shortenCommandLine();
-		}
-		CommandDetails cmd = new CommandDetails();
+
 		cmd.setCommandLine(cmdLine);
 		cmd.setEnvp(envp);
 		cmd.setWorkingDir(workingDir);
-		cmd.setClasspathShortener(classpathShortener);
-		cmd.setCommandLineShortener(commandLineShortener);
 		subMonitor.worked(1);
 		return cmd;
 	}
@@ -524,7 +549,7 @@ public class StandardVMRunner extends AbstractVMRunner {
 			return;
 		}
 		String timestamp = DateFormat.getDateTimeInstance(DateFormat.MEDIUM, DateFormat.MEDIUM).format(new Date(System.currentTimeMillis()));
-		IProcess process= newProcess(launch, p, renderProcessLabel(cmdLine, timestamp), getDefaultProcessMap());
+		IProcess process = newProcess(launch, p, renderProcessLabel(p, cmdLine, timestamp), getDefaultProcessMap());
 		process.setAttribute(DebugPlugin.ATTR_PATH, cmdLine[0]);
 		process.setAttribute(IProcess.ATTR_CMDLINE, renderCommandLine(cmdLine));
 		String ltime = launch.getAttribute(DebugPlugin.ATTR_LAUNCH_TIMESTAMP);
@@ -537,9 +562,9 @@ public class StandardVMRunner extends AbstractVMRunner {
 			Arrays.sort(envp);
 			process.setAttribute(DebugPlugin.ATTR_ENVIRONMENT, String.join(String.valueOf('\n'), envp));
 		}
-		if (!cmdDetails.getClasspathShortener().getProcessTempFiles().isEmpty()
-				|| !cmdDetails.getCommandLineShortener().getProcessTempFiles().isEmpty()) {
-			String tempFiles = Stream.concat(cmdDetails.getClasspathShortener().getProcessTempFiles().stream(), cmdDetails.getCommandLineShortener().getProcessTempFiles().stream()).map(File::getAbsolutePath).collect(Collectors.joining(File.pathSeparator));
+		List<File> processTempFiles = cmdDetails.getCommandLineShortener().getProcessTempFiles();
+		if (!processTempFiles.isEmpty()) {
+			String tempFiles = processTempFiles.stream().map(File::getAbsolutePath).collect(Collectors.joining(File.pathSeparator));
 			process.setAttribute(LaunchingPlugin.ATTR_LAUNCH_TEMP_FILES, tempFiles);
 		}
 		subMonitor.worked(1);
