@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2005, 2018 IBM Corporation and others.
+ *  Copyright (c) 2005, 2022 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -447,6 +447,7 @@ class ExecutionEnvironment implements IExecutionEnvironment {
 	 * @param path bundle relative path to properties file
 	 * @return properties or <code>null</code> if none
 	 */
+	@SuppressWarnings("deprecation")
 	private Properties getJavaProfileProperties(Bundle bundle, String path) {
 		Properties profile = new Properties();
 		URL profileURL = bundle.getEntry(path);
@@ -461,18 +462,30 @@ class ExecutionEnvironment implements IExecutionEnvironment {
 				return null;
 			}
 		} else {
-			if (getCompliance() == null) {
+			String compliance = getCompliance();
+			if (compliance == null) {
 				return null;
 			}
-			profile.setProperty(JavaCore.COMPILER_COMPLIANCE, getCompliance());
-			profile.setProperty(JavaCore.COMPILER_SOURCE, getCompliance());
-			profile.setProperty(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, getCompliance());
-			profile.setProperty("org.eclipse.jdt.core.compiler.problem.assertIdentifier", "error"); //$NON-NLS-1$ //$NON-NLS-2$
-			profile.setProperty("org.eclipse.jdt.core.compiler.problem.enumIdentifier", "error"); //$NON-NLS-1$ //$NON-NLS-2$
-			profile.setProperty(Constants.FRAMEWORK_EXECUTIONENVIRONMENT, calculateVMExecutionEnvs(new Version(getCompliance())));
+			profile.setProperty(JavaCore.COMPILER_COMPLIANCE, compliance);
+			profile.setProperty(JavaCore.COMPILER_SOURCE, compliance);
+			profile.setProperty(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, compliance);
+			profile.setProperty(JavaCore.COMPILER_PB_ASSERT_IDENTIFIER, JavaCore.ERROR);
+			profile.setProperty(JavaCore.COMPILER_PB_ENUM_IDENTIFIER, JavaCore.ERROR);
+			profile.setProperty(Constants.FRAMEWORK_EXECUTIONENVIRONMENT, calculateVMExecutionEnvs(new Version(compliance)));
 			profile.setProperty(JavaCore.COMPILER_RELEASE, JavaCore.ENABLED);
+			if (JavaCore.compareJavaVersions(compliance, JavaCore.VERSION_10) > 0) {
+				profile.setProperty(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, JavaCore.DISABLED);
+				profile.setProperty(JavaCore.COMPILER_PB_REPORT_PREVIEW_FEATURES, JavaCore.WARNING);
+			}
 
 		}
+		// For below Java 9 EE, compiler release option should be disabled by default
+		String property = profile.getProperty(JavaCore.COMPILER_COMPLIANCE);
+		if (property != null) {
+			if (JavaCore.compareJavaVersions(property, JavaCore.VERSION_9) < 0) {
+				profile.setProperty(JavaCore.COMPILER_RELEASE, JavaCore.DISABLED);
+			}
+		}
 		return profile;
 	}
 
@@ -558,4 +571,9 @@ class ExecutionEnvironment implements IExecutionEnvironment {
 	private String getCompliance() {
 		return fElement.getAttribute("compliance"); //$NON-NLS-1$
 	}
+
+	@Override
+	public String toString() {
+		return this.fElement.getAttribute("id"); //$NON-NLS-1$
+	}
 }
