@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -32,6 +32,7 @@ import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IMarker;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
+import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
@@ -51,9 +52,12 @@ import org.eclipse.debug.core.model.IBreakpoint;
 import org.eclipse.debug.core.model.LaunchConfigurationDelegate;
 import org.eclipse.debug.core.sourcelookup.ISourceLookupDirector;
 import org.eclipse.jdt.core.IClasspathAttribute;
+import org.eclipse.jdt.core.IClasspathEntry;
+import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaModelMarker;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IModuleDescription;
+import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.debug.core.IJavaDebugTarget;
 import org.eclipse.jdt.debug.core.IJavaMethodBreakpoint;
@@ -318,13 +322,10 @@ public abstract class AbstractJavaLaunchConfigurationDelegate extends LaunchConf
 		IRuntimeClasspathEntry jreEntry = null;
 		while (jreEntry == null && index < entries.length) {
 			IRuntimeClasspathEntry entry = entries[index++];
-			if (entry.getClasspathProperty() == IRuntimeClasspathEntry.BOOTSTRAP_CLASSES
-					|| entry.getClasspathProperty() == IRuntimeClasspathEntry.STANDARD_CLASSES) {
-				if (JavaRuntime.isVMInstallReference(entry)) {
-					jreEntry = entry;
-				} else {
-					bootEntriesPrepend.add(entry);
-				}
+			if (JavaRuntime.isVMInstallReference(entry)) {
+				jreEntry = entry;
+			} else if (entry.getClasspathProperty() == IRuntimeClasspathEntry.BOOTSTRAP_CLASSES) {
+				bootEntriesPrepend.add(entry);
 			}
 		}
 		IRuntimeClasspathEntry[] bootEntriesPrep = JavaRuntime
@@ -469,22 +470,27 @@ public abstract class AbstractJavaLaunchConfigurationDelegate extends LaunchConf
 		for (IRuntimeClasspathEntry entry : entries) {
 			String location = entry.getLocation();
 			if (location != null) {
-				if (entry.getClasspathProperty() == IRuntimeClasspathEntry.USER_CLASSES) {
+				switch (entry.getClasspathProperty()) {
+				case IRuntimeClasspathEntry.USER_CLASSES:
 					if (!classpathSet.contains(location)) {
 						classpathEntries.add(location);
 						classpathSet.add(location);
 					}
-				} else if (entry.getClasspathProperty() == IRuntimeClasspathEntry.CLASS_PATH) {
+					break;
+				case IRuntimeClasspathEntry.CLASS_PATH:
 					if (!classpathSet.contains(location)) {
 						classpathEntries.add(location);
 						classpathSet.add(location);
 					}
-
-				} else if (entry.getClasspathProperty() == IRuntimeClasspathEntry.MODULE_PATH) {
+					break;
+				case IRuntimeClasspathEntry.MODULE_PATH:
 					if (!modulepathSet.contains(location)) {
 						modulepathEntries.add(location);
 						modulepathSet.add(location);
 					}
+					break;
+				default:
+					break;
 				}
 
 			}
@@ -1158,19 +1164,42 @@ public abstract class AbstractJavaLaunchConfigurationDelegate extends LaunchConf
 					IModuleDescription moduleDescription = javaProject == null ? null : javaProject.getModuleDescription();
 					if (moduleDescription != null) {
 						String moduleName = moduleDescription.getElementName();
-						String locations = moduleToLocations.get(moduleName);
-						if (locations == null) {
-							moduleToLocations.put(moduleName, location);
-						} else {
-							moduleToLocations.put(moduleName, locations + File.pathSeparator + location);
-						}
+						addPatchModuleLocations(moduleToLocations, moduleName, location);
 					} else {
 						// should not happen, log?
 					}
+				} else {
+					for (IClasspathAttribute attribute : entry.getClasspathEntry().getExtraAttributes()) {
+						if (IClasspathAttribute.PATCH_MODULE.equals(attribute.getName())) {
+							String patchModules = attribute.getValue();
+							for (String patchModule : patchModules.split("::")) { //$NON-NLS-1$
+								int equalsIdx = patchModule.indexOf('=');
+								if (equalsIdx != -1) {
+									if (equalsIdx < patchModule.length() - 1) { // otherwise malformed?
+										String locations = toAbsolutePathsString(patchModule.substring(equalsIdx + 1));
+										String moduleName = patchModule.substring(0, equalsIdx);
+										addPatchModuleLocations(moduleToLocations, moduleName, locations);
+									}
+								} else {
+									// old (discouraged) format without explicit paths: list all output locations of the current project
+									IJavaProject javaProject = JavaRuntime.getJavaProject(configuration);
+									addPatchModuleLocations(moduleToLocations, patchModule, toAbsolutePathsString(javaProject.getOutputLocation().toString()));
+									for (IClasspathEntry cpEntry : javaProject.getRawClasspath()) {
+										if (cpEntry.getOutputLocation() != null) {
+											addPatchModuleLocations(moduleToLocations, patchModule, toAbsolutePathsString(cpEntry.getOutputLocation().toString()));
+										}
+									}
+								}
+							}
+
+							break;
+						}
+					}
 				}
 			}
 		}
-		if (moduleToLocations.isEmpty()) {
+		String addModules = configuration.getAttribute(IJavaLaunchConfigurationConstants.ATTR_SPECIAL_ADD_MODULES, ""); //$NON-NLS-1$
+		if (moduleToLocations.isEmpty() && addModules.isEmpty()) {
 			return moduleCLIOptions;
 		}
 
@@ -1194,9 +1223,71 @@ public abstract class AbstractJavaLaunchConfigurationDelegate extends LaunchConf
 				}
 			}
 		}
+		if (!addModules.isEmpty()) {
+			list.add("--add-modules"); //$NON-NLS-1$
+			list.add(addModules);
+		}
 		return DebugPlugin.renderArguments(list.toArray(new String[list.size()]), null);
 	}
 
+	private void addPatchModuleLocations(Map<String, String> moduleToLocations, String moduleName, String locations) {
+		String existing = moduleToLocations.get(moduleName);
+		if (existing == null) {
+			moduleToLocations.put(moduleName, locations);
+		} else {
+			moduleToLocations.put(moduleName, existing + File.pathSeparator + locations);
+		}
+	}
+
+	private static String toAbsolutePathsString(String fPaths) {
+		String[] paths = fPaths.split(File.pathSeparator);
+		String[] absPaths = new String[paths.length];
+		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
+		for (int i = 0; i < paths.length; i++) {
+			IResource resource = root.findMember(new Path(paths[i]));
+			try {
+				absPaths[i] = toAbsolutePath(resource, root);
+			} catch (CoreException e) {
+				LaunchingPlugin.log(e);
+			}
+			if (absPaths[i] == null) {
+				absPaths[i] = paths[i];
+			}
+		}
+		String allPaths = String.join(File.pathSeparator, absPaths);
+		return allPaths;
+	}
+
+	private static String toAbsolutePath(IResource resource, IWorkspaceRoot root) throws CoreException {
+		IJavaElement element = JavaCore.create(resource);
+		if (element != null && element.exists()) {
+			if (element instanceof IJavaProject) {
+				Set<String> paths = new HashSet<>();
+				IJavaProject project = (IJavaProject) element;
+				paths.add(absPath(root, project.getOutputLocation()));
+				for (IClasspathEntry entry : project.getResolvedClasspath(true)) {
+					if (entry.getEntryKind() == IClasspathEntry.CPE_SOURCE && entry.getOutputLocation() != null) {
+						paths.add(absPath(root, entry.getOutputLocation()));
+					}
+				}
+				return String.join(File.pathSeparator, paths);
+			} else if (element instanceof IPackageFragmentRoot) {
+				IPackageFragmentRoot packageRoot = (IPackageFragmentRoot) element;
+				IClasspathEntry entry = packageRoot.getJavaProject().getClasspathEntryFor(resource.getFullPath());
+				return absPath(root, entry.getOutputLocation());
+			}
+		}
+		if (resource != null) {
+			// non-source location as-is:
+			return resource.getLocation().toString();
+		}
+		return null;
+	}
+
+	private static String absPath(IWorkspaceRoot root, IPath path) {
+		return root.findMember(path).getLocation().toString();
+	}
+
 	/**
 	 * Supports modular class for launching.
 	 *
