@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -111,7 +111,7 @@ public class JavaLaunchDelegate extends AbstractJavaLaunchConfigurationDelegate
 					if (modName != null && modName.length() > 0) {
 						String defaultModuleName = null;
 						String moduleName = configuration.getAttribute(IJavaLaunchConfigurationConstants.ATTR_MODULE_NAME, defaultModuleName);
-						if (moduleName != null) {
+						if (moduleName != null && !moduleName.isEmpty()) {
 							runConfig.setModuleDescription(moduleName);
 						} else {
 							runConfig.setModuleDescription(modName);
